@@ -1,3 +1,237 @@
+static char *xpm_font[] = {
+" 5 24 3 1",
+"  c None",
+"# c Black",
+"     ",
+"     ",
+"#####",
+"  #  ",
+"  #  ",
+"  #  ",
+"  #  ",
+"  #  ",
+"  #  ",
+"     ",
+"     ",
+"    #",
+" ### ",
+"#    ",
+"     ",
+" ####",
+"# #  ",
+"  #  ",
+"  #  ",
+"  #  ",
+"  #  ",
+" #   ",
+"     ",
+"     "
+};
+static char *xpm_color[7][27] = {
+{
+" 3 24 3 1",
+"  c None",
+"# c Black",
+"   ",
+"   ",
+"   ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+"   ",
+"   "
+},
+{
+" 3 24 3 1",
+"  c None",
+"# c Blue",
+"   ",
+"   ",
+"   ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+"   ",
+"   "
+},
+{
+" 3 24 3 1",
+"  c None",
+"# c Green",
+"   ",
+"   ",
+"   ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+"   ",
+"   "
+},
+{
+" 3 24 3 1",
+"  c None",
+"# c Cyan",
+"   ",
+"   ",
+"   ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+"   ",
+"   "
+},
+{
+" 3 24 3 1",
+"  c None",
+"# c Red",
+"   ",
+"   ",
+"   ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+"   ",
+"   "
+},
+{
+" 3 24 3 1",
+"  c None",
+"# c Magenta",
+"   ",
+"   ",
+"   ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+"   ",
+"   "
+},
+{
+" 3 24 3 1",
+"  c None",
+"# c Yellow",
+"   ",
+"   ",
+"   ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+" # ",
+"   ",
+"   "
+}
+};
 static char *xpm_mark[] = {
 "24 24 3 1",
 "  c None",
@@ -705,7 +939,7 @@ static const char * xpm_rtext[] = {
 "                        ",
 "                        "};
 
-static const char * xpm_bond[18][12] = {
+static const char * xpm_bond[20][12] = {
 {
 "24 9 2 1",
 "       c None",
@@ -941,4 +1175,30 @@ static const char * xpm_bond[18][12] = {
 "                        ",
 "                        ",
 "                        "
+},{
+"24 9 2 1",
+"       c None",
+".      c #505000",
+"                        ",
+"                        ",
+"   ..................   ",
+"                        ",
+"   ..................   ",
+"                        ",
+"   ..................   ",
+"                        ",
+"                        "
+},{
+"24 9 2 1",
+"       c None",
+".      c #505000",
+"                        ",
+"   ..................   ",
+"                        ",
+"   ..................   ",
+"                        ",
+"   ..................   ",
+"                        ",
+"   ..................   ",
+"                        "
 }};
