@@ -1085,6 +1085,18 @@ bond_cut (int x, int y, int tx, int ty, int r)
   for (d = 0; d < hp->nc; d++)
     {
       hc = hp_a->c;
+#ifdef GTK2
+      n = (int)g_utf8_strlen (hp_a->c,-1);
+      for (i = 0; i < n; i++)
+	{
+	  if (Extra_char (*hc,1))
+	    {
+	      hc++;
+	      --n;
+	    }
+	  hc++;
+	}
+#else	
       n = (int)strlen (hp_a->c);
       for (i = 0; i < n; i++)
 	{
@@ -1095,6 +1107,7 @@ bond_cut (int x, int y, int tx, int ty, int r)
 	    }
 	  hc++;
 	}
+#endif
       if (x == hp_a->x && y == hp_a->y)
 	{
 	  if (hp_a->direct == -10)
