@@ -17,7 +17,7 @@
 #  endif
 #endif
 
-#define VERSION "1.6.3"
+#define VERSION "1.6.6"
 #define PIXMAPWIDTH 1600
 #define PIXMAPHEIGHT 1200
 
@@ -210,7 +210,7 @@ extern void copy_obj(void);
 
 extern int save_mol(FILE *fp, int partial);
 extern int load_mol(char *filename);
-extern int import_mdl_mol(char *filename);
+extern int import_mdl_mol(char *filename,int skip);
 extern int import_pdb(char *filename);
 extern int import_babel(char *filename);
 extern int add_mol(char *filename);
@@ -222,7 +222,7 @@ extern int export_latex_pic(char *filename, float scalefactor);
 extern int export_ps_pic(char *filename, float scalefactor);
 extern int print_ps_pic(char *filename);
 extern int export_fw(char *filename);
-extern int export_mdl_mol(char *filename);
+extern int export_mdl_mol(FILE *fp);
 extern int export_emf(char *filename);
 extern int readrc(void);
 extern int writerc(void);
@@ -296,6 +296,7 @@ void restore_picture(void);
 void getpreview(GtkWidget*, gint, gint,  GdkEventButton*, gpointer);
 void set_icon(GtkWidget*);
 extern int load_preview(char*);
+extern int preview_mdl_mol(char*, int);
 extern void pdbstore(void);
 double *pdbx, *pdby,*pdbz;
 int *bondfrom,*bondto;
@@ -326,3 +327,4 @@ int curfontsize=3;
 extern int undo_malloc(size_t);
 int atnum;
 int draw_ok=0;
+int sdfindex=0;
