@@ -17,7 +17,7 @@
 #  endif
 #endif
 
-#define VERSION "1.6.3"
+#define VERSION "1.6.6"
 #define PIXMAPWIDTH 1600
 #define PIXMAPHEIGHT 1200
 
@@ -171,7 +171,11 @@ extern void Drawstring( int, int, char*, int, int, int, int, int, int);
 extern void DrawCircle( int, int, int, int, int,int);
 extern void DrawDotted( int , int, int, int , int, int );
 extern void DrawAcross( int , int, int, int , int , int);
+#ifdef GTK2
+extern int Extra_char(gunichar c, int ha);
+#else
 extern int Extra_char(char c);
+#endif
 extern int Load_Font(void);
 extern void Set_Line(int);
 
@@ -222,8 +226,8 @@ extern int add_mol(char *filename);
 extern int export_bitmap(char *filename);
 extern int export_xfig(char *filename);
 extern int export_svg(char *filename);
-extern int export_mdl_mol(char *filename);
-extern int import_mdl_mol(char *filename);
+extern int export_mdl_mol(FILE *fp);
+extern int import_mdl_mol(char *filename,int skip);
 extern int import_pdb(char *filename);
 extern int export_latex_pic(char *filename,float scalefactor);
 extern int export_ps_pic(char *filename, float scalefactor);
@@ -285,4 +289,5 @@ extern char bghexcolor[10];
 extern int curfontsize;
 extern int atnum;
 extern int draw_ok;
+extern int sdfindex;
 /*@end@*/
