@@ -16,7 +16,7 @@ Add_atom (int event_x, int event_y)
   int x, y;
   int i;
 
-  name = gtk_entry_get_text (GTK_ENTRY (textbox)); 
+  name = (char*)gtk_entry_get_text (GTK_ENTRY (textbox)); 
   if (strlen (name))
     {
       x = round_coord (event_x, size_factor);
