@@ -5,8 +5,15 @@
 #include <string.h>
 
 #include "ct1.h"
+#ifdef GTK2
+PangoFontDescription *font[7], *smallfont[7], *symbfont[7], 
+                     *ssymbfont[7], *slfont[7], 
+                     *boldfont[7], *textfont[7];
+#else
 GdkFont *font[7], *smallfont[7], *symbfont[7], 
-*ssymbfont[7], *slfont[7], *boldfont[7], *textfont[7];
+                  *ssymbfont[7], *slfont[7], 
+                  *boldfont[7], *textfont[7];
+#endif
 
 #ifndef MIN
 #define MIN(a, b)        ((a) < (b) ? (a) : (b))
@@ -670,7 +677,7 @@ DrawWiggly (int x, int y, int tx, int ty, int active, int color)
     asin (copysign ((float) ylen / (float) veclen, (double) (xlen * -ylen) )) * 180. /
     3.14159);
 
-  boxlen = (int) 0.2 * veclen;
+  boxlen = (int) (0.2 * veclen);
   boxcorx = (int) ((1. - (float) xlen / (float) veclen) * boxlen / 2);
   boxcory = (int) ((1. - (float) ylen / (float) veclen) * boxlen / 2);
 
@@ -918,9 +925,18 @@ Drawspline (int x0, int y0, int x1, int y1, int x2, int y2, int x3, int y3,
       mypoints[i].y = (gint16) (py1 * size_factor);
     }
   npoints = 21;
-  if (type >= 0)
+  if (type >= 0) {
+ /* move end of last line segment back a bit to keep it from protruding 
+    beneath the arrowhead */
+    xbase= mypoints[20].x;
+    ybase= mypoints[20].y;
+    mypoints[20].x = mypoints[20].x - 0.03*(mypoints[20].x-mypoints[19].x);	
+    mypoints[20].y = mypoints[20].y - 0.03*(mypoints[20].y-mypoints[19].y);	
     gdk_draw_lines (picture, thegc, mypoints, npoints);
-
+    mypoints[20].x=xbase;
+    mypoints[20].y=ybase;
+    }
+    
   if (type == -1)
     gdk_draw_polygon (picture, thegc, TRUE, mypoints, npoints);
   if (type == -2)
@@ -929,19 +945,30 @@ Drawspline (int x0, int y0, int x1, int y1, int x2, int y2, int x3, int y3,
   if (type <= 0)
     return;
 
+  for (i=0;i<4;i++){ // find acceptable arrowhead length
+  xlen = mypoints[20].x - mypoints[19-i].x;
+  ylen = mypoints[20].y - mypoints[19-i].y;
+  xbase = mypoints[19-i].x;
+  ybase = mypoints[19-i].y;
+  if (xlen*xlen+ylen*ylen >200.0 *size_factor*size_factor) break;
+  
+  }
 
-  xlen = mypoints[20].x - mypoints[16].x;
-  ylen = mypoints[20].y - mypoints[16].y;
+  if (xlen*xlen+ylen*ylen >400.0 *size_factor*size_factor) {
+  xlen -= (mypoints[20].x - mypoints[19].x)/2;
+  ylen -= (mypoints[20].y - mypoints[19].y)/2;
+  xbase = mypoints[19].x +(mypoints[20].x - mypoints[19].x)/2 ;
+  ybase = mypoints[19].y +(mypoints[20].y - mypoints[19].y)/2 ;
+  }
 
   if (xlen != 0)
     xlen = (int) copysign (10. * size_factor, (double)xlen);
   if (ylen != 0)
     ylen = (int) copysign (10. * size_factor, (double)ylen);
-  xbase = mypoints[16].x;
-  ybase = mypoints[16].y;
 
-  mypoints[0].x = mypoints[20].x;	/* arrow tip at the end of the last */
-  mypoints[0].y = mypoints[20].y;	/* line segment */
+  /* tip of arrow at original endpoint of last line */
+  mypoints[0].x = mypoints[20].x;	
+  mypoints[0].y = mypoints[20].y;	
 
   /* calculate both possible positions for arrow side */
   mypoints[1].x = (gint16) (xbase + 0.5 * ylen);
@@ -992,14 +1019,24 @@ Drawstring (int x, int y, char *c, int direct, int active, int thecolor, int ser
 {
   int ha, tw, a;
   int nch, textl, chl, chr;
-  char *l, *hc, hl[2];
   int d, hx, n;
   int shiftall = 0;
   int variance[MAXCL];
+#ifdef GTK2
+  gchar *l="       ";
+  gunichar hc, hl;
+  gunichar text[MAXCL];
+  gunichar symbol[MAXCL];
+  gunichar slanted[MAXCL];
+  gunichar bold[MAXCL];
+  static PangoLayout *thelayout;
+#else
+  char *l, *hc, hl[2];
   char text[MAXCL];
   char symbol[MAXCL];
   char slanted[MAXCL];
   char bold[MAXCL];
+#endif
   GdkGC *thegc;
   int save_x, sub_lastx, sup_lastx;
   int fontsize;
@@ -1021,11 +1058,92 @@ Drawstring (int x, int y, char *c, int direct, int active, int thecolor, int ser
   x = x * size_factor;
   hx = x;
   y = y * size_factor;
-
+  
+#ifdef GTK2
+  if (!thelayout) thelayout = gtk_widget_create_pango_layout(drawing_area,"X");
+  pango_layout_set_font_description(thelayout,font[fontsize]);
+  pango_layout_get_pixel_size(thelayout, &tw, &a);  
+  pango_layout_set_text(thelayout, "x", -1);
+  pango_layout_set_font_description(thelayout,font[fontsize]);
+  pango_layout_get_pixel_size(thelayout, &tw, &ha);
+  ha = ha/2;
+  n = (int) g_utf8_strlen(c,-1);
+#else  
   a = gdk_char_height (font[fontsize], 'X');
   ha = gdk_char_height (font[fontsize], 'x') / 2;
   n = (int)strlen (c);
+#endif
 
+
+#ifdef GTK2
+  for (d = 0; d < n; d++)
+    {
+      symbol[d] = FALSE;
+      slanted[d] = FALSE;
+      bold[d]=FALSE;
+      
+      hc = g_utf8_get_char(c);
+      
+      if (shiftall != 0)
+	{
+	  if (hc == '}')
+	    {
+	      shiftall = 0;
+	      if (!(hc=g_utf8_get_char(c)))continue;
+	      --n;
+	    }
+	  variance[d] = shiftall;
+	}
+      if (shiftall == 0)
+	{
+	  if ((variance[d] = Extra_char (hc,ha)) != 0)
+	    {
+	      c=g_utf8_next_char(c);
+	      if ((hc=g_utf8_get_char(c)))
+		{
+		  --n;
+		  if (hc == '{')
+		    {
+		      shiftall = variance[d];
+		      --n;
+		    }
+		}
+	      else
+		{
+		  variance[d] = 0;
+		}
+	    }
+	}
+      text[d] = hc;
+      c = g_utf8_next_char(c);
+      if (text[d] == '@' && (hl=g_utf8_get_char(c)))
+	{
+	  symbol[d] = TRUE;
+	  text[d] = hl;
+	  --n;
+	}
+
+      else if (text[d] == '|' && (hl=g_utf8_get_char(c)))
+	{
+	  slanted[d] = TRUE;
+	  text[d] = hl;
+	  --n;
+	}
+
+      else if (text[d] == '#' && (hl=g_utf8_get_char(c)))
+	{
+	  bold[d] = TRUE;
+	  text[d] = hl;
+	  --n;
+	}
+
+      else if (text[d] == '\\' && (hl=g_utf8_get_char(c)))
+	{
+	text[d] = ' ';
+	}
+    }
+
+#else
   hc = c;
   for (d = 0; d < n; d++)
     {
@@ -1088,12 +1206,10 @@ Drawstring (int x, int y, char *c, int direct, int active, int thecolor, int ser
 
       else if (text[d] == '\\' && *hc)
 	{
-/*	  text[d] = *hc++;
-	  --n;
-*/
 	text[d] = ' ';
 	}
     }
+#endif
 
   nch = n;
   if (nch > 0)
@@ -1103,12 +1219,28 @@ Drawstring (int x, int y, char *c, int direct, int active, int thecolor, int ser
       x = save_x = sub_lastx = sup_lastx = 0;
       for (d = 0; d < nch; d++)
 	{
+#ifdef GTK2
+          l = g_locale_to_utf8((const gchar*) &text[d],1,NULL,NULL,NULL);
+#endif          
 	  if (variance[d])
 	    {
+#ifdef GTK2
+              pango_layout_set_text(thelayout,l,-1);
+              pango_layout_set_font_description(thelayout,smallfont[fontsize]);
+              pango_layout_get_pixel_size(thelayout, &tw, &a);
+#else             
 	      tw = gdk_char_width (smallfont[fontsize], text[d]) + 2;
+#endif
 	      if (symbol[d])
+#ifdef GTK2
+                {
+                  pango_layout_set_text(thelayout,l,-1);
+                  pango_layout_set_font_description(thelayout,ssymbfont[fontsize]);
+                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                }
+#else                
 		tw = gdk_char_width (ssymbfont[fontsize], text[d]);
-
+#endif
 	      if (variance[d] < 0)
 		{
 		  if (save_x < x)
@@ -1124,14 +1256,43 @@ Drawstring (int x, int y, char *c, int direct, int active, int thecolor, int ser
 	    }
 	  else /* not sub- or superscripted */
 	    {
+#ifdef GTK2
+                  pango_layout_set_text(thelayout,l,-1);
+                  pango_layout_set_font_description(thelayout,font[fontsize]);
+                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+#else
 	      tw = 1 + gdk_char_width (font[fontsize], text[d]);
+#endif
 	      if (symbol[d])
+#ifdef GTK2
+                {
+                  pango_layout_set_text(thelayout,l,-1);
+                  pango_layout_set_font_description(thelayout,symbfont[fontsize]);
+                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                }
+#else                
 		tw = gdk_char_width (symbfont[fontsize], text[d]);
+#endif
 	      if (bold[d])
+#ifdef GTK2
+                {
+                  pango_layout_set_text(thelayout,l,-1);
+                  pango_layout_set_font_description(thelayout,boldfont[fontsize]);
+                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                }
+#else                
 	      	tw = gdk_char_width (boldfont[fontsize], text[d]);
+#endif
 	      if (slanted[d])
+#ifdef GTK2
+                {
+                  pango_layout_set_text(thelayout,l,-1);
+                  pango_layout_set_font_description(thelayout,slfont[fontsize]);
+                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                }
+#else                
 		tw = 1 + gdk_char_width (slfont[fontsize], text[d]);
-
+#endif
 	      if (save_x < x)
 		{
 		  if (sub_lastx < sup_lastx)
@@ -1167,9 +1328,25 @@ Drawstring (int x, int y, char *c, int direct, int active, int thecolor, int ser
     {
       if (variance[d])
 	{
+#ifdef GTK2
+                {
+                  pango_layout_set_text(thelayout,l,-1);
+                  pango_layout_set_font_description(thelayout,smallfont[fontsize]);
+                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                }
+#else                
 	  tw = gdk_char_width (smallfont[fontsize], text[d]) + 2;
+#endif
 	  if (symbol[d])
+#ifdef GTK2
+                {
+                  pango_layout_set_text(thelayout,l,-1);
+                  pango_layout_set_font_description(thelayout,ssymbfont[fontsize]);
+                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                }
+#else                
 	    tw = gdk_char_width (ssymbfont[fontsize], text[d]);
+#endif
 	  if (variance[d] < 0)
 	    {
 	      if (save_x < x)
@@ -1185,13 +1362,43 @@ Drawstring (int x, int y, char *c, int direct, int active, int thecolor, int ser
 	}
       else
 	{ /* not sub- or superscripted */
+#ifdef GTK2
+                  pango_layout_set_text(thelayout,l,-1);
+                  pango_layout_set_font_description(thelayout,font[fontsize]);
+                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+#else                
 	  tw = 1 + gdk_char_width (font[fontsize], text[d]);
+#endif
 	  if (symbol[d])
+#ifdef GTK2
+                {
+                  pango_layout_set_text(thelayout,l,-1);
+                  pango_layout_set_font_description(thelayout,symbfont[fontsize]);
+                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                }
+#else                
 	    tw = gdk_char_width (symbfont[fontsize], text[d]);
+#endif
 	  if (bold[d])
+#ifdef GTK2
+                {
+                  pango_layout_set_text(thelayout,l,-1);
+                  pango_layout_set_font_description(thelayout,boldfont[fontsize]);
+                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                }
+#else                
 	    tw = gdk_char_width (boldfont[fontsize], text[d]);
+#endif	    
 	  if (slanted[d])
+#ifdef GTK2
+                {
+                  pango_layout_set_text(thelayout,l,-1);
+                  pango_layout_set_font_description(thelayout,slfont[fontsize]);
+                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                }
+#else                
 	    tw = 1 + gdk_char_width (slfont[fontsize], text[d]);
+#endif
 	  if (save_x < x)
 	    {
 	      if (sub_lastx < sup_lastx)
@@ -1219,18 +1426,44 @@ Drawstring (int x, int y, char *c, int direct, int active, int thecolor, int ser
 
   n = nch;
   x = hx;
+
+#ifdef GTK2  
+  y -= a ;
+#endif
+  
   save_x = sub_lastx = sup_lastx = x;
   for (d = 0; d < n; d++)
     {
+#ifdef GTK2
+//      l = g_locale_to_utf8((gchar*)text[d],1,NULL,NULL,NULL);
+	g_unichar_to_utf8((gunichar)text[d], l);
+#else      
       hl[0] = text[d];
       hl[1] = 0;
       l = &hl[0];
+#endif
 
       if (variance[d])
 	{
+#ifdef GTK2
+                {
+                  pango_layout_set_text(thelayout,l,-1);
+                  pango_layout_set_font_description(thelayout,smallfont[fontsize]);
+                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                }
+#else                
 	  tw = gdk_char_width (smallfont[fontsize], text[d]) + 2;
+#endif
 	  if (symbol[d])
+#ifdef GTK2
+                {
+                  pango_layout_set_text(thelayout,l,-1);
+                  pango_layout_set_font_description(thelayout,ssymbfont[fontsize]);
+                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                }
+#else                
 	    tw = gdk_char_width (ssymbfont[fontsize], text[d]);
+#endif
 
 	  if (variance[d] < 0)
 	    {
@@ -1247,32 +1480,75 @@ Drawstring (int x, int y, char *c, int direct, int active, int thecolor, int ser
 
 	  if (symbol[d])
 	    {
+#ifdef GTK2
+              pango_layout_set_text(thelayout,l,-1);
+              pango_layout_set_font_description(thelayout,ssymbfont[fontsize]);
+              gdk_draw_layout(picture,background_gc,x,y+ha+variance[d],thelayout);
+              gdk_draw_layout(picture,thegc,x,y+ha+variance[d],thelayout);
+#else
 	      gdk_draw_text (picture, ssymbfont[fontsize],
 			     background_gc, x,
 			     y + ha + variance[d], l, (gint)strlen (l));
 	      gdk_draw_text (picture, ssymbfont[fontsize], thegc, x,
 			     y + ha + variance[d], l, (gint)strlen (l));
+#endif
 	    }
 	  else
 	    {
+#ifdef GTK2
+              pango_layout_set_text(thelayout,l,-1);
+              pango_layout_set_font_description(thelayout,smallfont[fontsize]);
+              gdk_draw_layout(picture,background_gc,x,y+ha+variance[d],thelayout);
+              gdk_draw_layout(picture,thegc,x,y+ha+variance[d],thelayout);
+#else
 	      gdk_draw_text (picture, smallfont[fontsize],
 			     background_gc, x,
 			     y + ha + variance[d], l, (gint)strlen (l));
 	      gdk_draw_text (picture, smallfont[fontsize], thegc, x,
 			     y + ha + variance[d], l, (gint)strlen (l));
+#endif
 	    }
 	  x = x + tw;
 	}
       else /* not sub- or superscripted */
 	{
+#ifdef GTK2
+              pango_layout_set_text(thelayout,l,-1);
+              pango_layout_set_font_description(thelayout,font[fontsize]);
+              pango_layout_get_pixel_size(thelayout,&tw,&a);
+#else
 	  tw = 1 + gdk_char_width (font[fontsize], text[d]);
+#endif	  
 	  if (symbol[d])
+#ifdef GTK2
+            {
+              pango_layout_set_text(thelayout,l,-1);
+              pango_layout_set_font_description(thelayout,symbfont[fontsize]);
+              pango_layout_get_pixel_size(thelayout,&tw,&a);
+             } 
+#else
 	    tw = gdk_char_width (symbfont[fontsize], text[d]);
+#endif	    
 	  if (bold[d])
+#ifdef GTK2
+            {
+              pango_layout_set_text(thelayout,l,-1);
+              pango_layout_set_font_description(thelayout,boldfont[fontsize]);
+              pango_layout_get_pixel_size(thelayout,&tw,&a);
+             } 
+#else
 	    tw = gdk_char_width (boldfont[fontsize], text[d]);
+#endif	    
 	  if (slanted[d])
+#ifdef GTK2
+            {
+              pango_layout_set_text(thelayout,l,-1);
+              pango_layout_set_font_description(thelayout,slfont[fontsize]);
+              pango_layout_get_pixel_size(thelayout,&tw,&a);
+             } 
+#else
 	    tw = 1 + gdk_char_width (slfont[fontsize], text[d]);
-
+#endif
 	  if (save_x < x)
 	    {
 	      if (sub_lastx < sup_lastx)
@@ -1283,34 +1559,69 @@ Drawstring (int x, int y, char *c, int direct, int active, int thecolor, int ser
 
 	  if (symbol[d])
 	    {
+#ifdef GTK2
+              pango_layout_set_text(thelayout,l,-1);
+              pango_layout_set_font_description(thelayout,symbfont[fontsize]);
+              gdk_draw_layout(picture,background_gc,x,y+ha,thelayout);
+              gdk_draw_layout(picture,thegc,x,y+ha,thelayout);
+#else
 	      gdk_draw_text (picture, symbfont[fontsize], background_gc,
 			     x, y + ha, l, (gint)strlen (l));
 	      gdk_draw_text (picture, symbfont[fontsize], thegc, x, y + ha, l,
 			     (gint)strlen (l));
+#endif
 	    }
 	  else if (bold[d])
 	    {
+#ifdef GTK2
+              pango_layout_set_text(thelayout,l,-1);
+              pango_layout_set_font_description(thelayout,boldfont[fontsize]);
+              gdk_draw_layout(picture,background_gc,x,y+ha,thelayout);
+              gdk_draw_layout(picture,thegc,x,y+ha,thelayout);
+#else
 	      gdk_draw_text (picture, boldfont[fontsize], background_gc,
 			     x, y + ha, l, (gint)strlen (l));
 	      gdk_draw_text (picture, boldfont[fontsize], thegc, x, y + ha, l, (gint)strlen (l));
+#endif
 	    }
 	  else if (slanted[d])
 	    {
+#ifdef GTK2
+              pango_layout_set_text(thelayout,l,-1);
+              pango_layout_set_font_description(thelayout,slfont[fontsize]);
+              gdk_draw_layout(picture,background_gc,x,y+ha,thelayout);
+              gdk_draw_layout(picture,thegc,x,y+ha,thelayout);
+#else
 	      gdk_draw_text (picture, slfont[fontsize], background_gc,
 			     x, y + ha, l, (gint)strlen (l));
 	      gdk_draw_text (picture, slfont[fontsize], thegc, x, y + ha, l, (gint)strlen (l));
+#endif
 	    }
 	  else if (serif_flag)
 	    {
+#ifdef GTK2
+              pango_layout_set_text(thelayout,l,-1);
+              pango_layout_set_font_description(thelayout,textfont[fontsize]);
+              gdk_draw_layout(picture,background_gc,x,y+ha,thelayout);
+              gdk_draw_layout(picture,thegc,x,y+ha,thelayout);
+#else
 	      gdk_draw_text (picture, textfont[fontsize], background_gc,
 			     x, y + ha, l, (gint)strlen (l));
 	      gdk_draw_text (picture, textfont[fontsize], thegc, x, y + ha, l, (gint)strlen (l));
+#endif
 	    }
 	  else
 	    {
+#ifdef GTK2
+              pango_layout_set_text(thelayout,l,-1);
+              pango_layout_set_font_description(thelayout,font[fontsize]);
+              gdk_draw_layout(picture,background_gc,x,y+ha,thelayout);
+              gdk_draw_layout(picture,thegc,x,y+ha,thelayout);
+#else
 	      gdk_draw_text (picture, font[fontsize], background_gc,
 			     x, y + ha, l, (gint)strlen (l));
 	      gdk_draw_text (picture, font[fontsize], thegc, x, y + ha, l, (gint)strlen (l));
+#endif
 	    }
 	  x = x + tw;
 	  save_x = sub_lastx = sup_lastx = x;
@@ -1318,11 +1629,18 @@ Drawstring (int x, int y, char *c, int direct, int active, int thecolor, int ser
     }
 }
 
+#ifdef GTK2
+int
+Extra_char (gunichar c, int ha)
+#else
 int
 Extra_char (char c)
+#endif
 /* process control characters for sub- and superscripting */
 {
+#ifndef GTK2
   int ha = gdk_char_height (font[zoom_factor], 'x') / 2;
+#endif
   if (c == '_')
     return (ha);
   if (c == '^')
@@ -1334,6 +1652,45 @@ int
 Load_Font ()
 /* load the normal, subscript and symbol fonts for all zoom scales */
 {
+
+#ifdef GTK2
+
+int i;
+
+  gchar *pangosymtype[]= {"Symbol 8", "Symbol 10", "Symbol 12", "Courier 14",
+                          "Symbol 18", "Symbol 20", "Symbol 24" };
+  gchar *pangossymtype[]= {"Symbol 8", "Symbol 8", "Symbol 10", "Courier 12",
+                          "Symbol 14", "Symbol 18", "Symbol 24" };
+  gchar *pangofntype[]= { "Helvetica 8", "Helvetica 10", "Helvetica 12",
+                          "Helvetica 14", "Helvetica 17", "Helvetica 20", 
+                          "Helvetica 24"};
+  gchar *pangosfntype[]= { "Helvetica 8", "Helvetica 8", "Helvetica 10",
+                           "Helvetica 12", "Helvetica 14", "Helvetica 14", 
+                           "Helvetica 20"};
+  gchar *pangosltype[]= { "Helvetica oblique 8", "Helvetica oblique 10",
+                          "Helvetica oblique 12",  "Helvetica oblique 14",
+                          "Helvetica oblique 18", "Helvetica oblique 18",
+                          "Helvetica oblique 24"};
+  gchar *pangobtype[]= { "Helvetica bold 8", "Helvetica bold 10",
+                         "Helvetica bold 12",  "Helvetica bold 14",
+                         "Helvetica bold 18", "Helvetica bold 18",
+                         "Helvetica bold 24"};
+  gchar *pangotexttype[]= { "Times 8", "Times 10",
+                            "Times 12",  "Times 14",
+                            "Times 18", "Times 18",
+                            "Times 24"};
+  for (i=0;i<7;i++){
+  font[i]=pango_font_description_from_string(pangofntype[i]);
+  symbfont[i]=pango_font_description_from_string(pangosymtype[i]);
+  ssymbfont[i]=pango_font_description_from_string(pangossymtype[i]);
+  smallfont[i]=pango_font_description_from_string(pangosfntype[i]);
+  slfont[i]=pango_font_description_from_string(pangosltype[i]);
+  boldfont[i]=pango_font_description_from_string(pangobtype[i]);
+  textfont[i]=pango_font_description_from_string(pangotexttype[i]);
+  }                                                                                                                                                                                                                                                                                                                           
+
+#else
+
 int i,fnt;
 
 /* NB: entries 0 and 1 are used for preview only, the default font is 4(!) */
@@ -1360,8 +1717,8 @@ int i,fnt;
   gchar *fntype75[] =
     { "*-helvetica-medium-r-normal--8-*", "*-helvetica-medium-r-normal--10-*",
     "*-helvetica-medium-r-normal--12-*", "*-helvetica-medium-r-normal--14-*",
-    "*-helvetica-medium-r-normal--17-*",
-    "*-helvetica-medium-r-normal--20-*", "*-helvetica-medium-r-normal--24-*"
+    "*-helvetica-medium-r-normal--18-*",
+    "*-helvetica-medium-r-normal--18-*", "*-helvetica-medium-r-normal--24-*"
   };
 
   gchar *fntype100[] =
@@ -1478,6 +1835,9 @@ for (i=0;i<7;i++) {
 	if ((textfont[i] = gdk_font_load (texttype100[fnt])) == NULL)
     textfont[i] = font[i];
  } 
+
+#endif
+
   return (1);
 }
 
