@@ -67,3 +67,6 @@ struct xfig_ellipse {
 #include <X11/Xlib.h>
 double pdbxcent,pdbycent,pdbzcent;
 
+extern struct xy_co *bond_cut(int x, int y, int tx, int ty, int r);
+
+extern int has_label (int, int);
