@@ -58,10 +58,30 @@
 				(mem) != BLOCK_END(block); \
 				(mem) = MEMORY_NEXT(mem))
 
+/* Some systems define MAP_ANON instead of MAP_ANONYMOUS. */
+/* Some (e.g. Solaris <8) have neither, but  map /dev/zero instead */
+#ifndef MAP_ANONYMOUS
+#ifdef MAP_ANON
+#define MAP_ANONYMOUS MAP_ANON
+#else
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+static int dev_zero_fd;
+#endif /* MAP_ANON */
+#endif /* MAP_ANONYMOUS */
+
+#ifdef MAP_ANONYMOUS
 #define MAP_NEW_ANON_AT_FLAGS(pos, size, flags) \
             (mmap((pos), (size), \
 			      PROT_READ | PROT_WRITE | PROT_EXEC, \
-				  MAP_PRIVATE | MAP_ANONYMOUS | (flags), 0, 0))
+				  MAP_PRIVATE | MAP_ANONYMOUS | (flags),-1, 0))
+#else
+#define MAP_NEW_ANON_AT_FLAGS(pos, size, flags) \
+            (mmap((pos), (size), \
+			      PROT_READ | PROT_WRITE | PROT_EXEC, \
+				  MAP_PRIVATE | (flags),dev_zero_fd, 0))
+#endif				  
 #define MAP_NEW_ANON(size) MAP_NEW_ANON_AT_FLAGS(0, (size), 0)
 #define MAP_NEW_ANON_AT(pos, size) \
             MAP_NEW_ANON_AT_FLAGS((pos), (size), MAP_FIXED)
@@ -81,7 +101,7 @@
 
 #define UNDO_SUCCESS            return UNDO_NOERROR;
 #define UNDO_ERROR(err)         return (undo_set_error(err), (err));
-#define UNDO_ERROR_NULL(err)    return (undo_set_error(err), NULL);
+#define UNDO_ERROR_NULL(err)    return (undo_set_error(err), (void*)NULL);
 
 #ifdef LIBUNDO
 void undo_set_error (int err);
@@ -203,6 +223,7 @@ int undo_memory_set (UNDO_MEMORY * memory, UNDO_MEMORY_STREAM * stream);
 
 static UNDO *undo_session = NULL;
 
+
 int
 undo_new (char *session_name)
 {
@@ -213,6 +234,10 @@ undo_new (char *session_name)
   if (undo_session == NULL)
     UNDO_ERROR (UNDO_NOMEM);
 
+#ifndef MAP_ANONYMOUS
+dev_zero_fd = open("/dev/zero",O_RDONLY);
+#endif
+
   undo_session->name = (char *) malloc (strlen (session_name) + 1);
   if (undo_session->name == NULL)
     {
@@ -254,7 +279,10 @@ undo_destroy (void)
     undo_history_destroy (undo_session->history);
 
   undo_session = NULL;
-
+#ifndef MAP_ANONYMOUS
+	close(dev_zero_fd);
+#endif
+	
   UNDO_SUCCESS;
 }
 
